#############################################################
#
#   Program: cdc_zscore.R
#   Project: IeDEA TB project 
#   PI:  
#   Statistican/Programmer: Meridith Blevins, MS
#   Purpose: Calculate the weight-for-age Z-score using CDC data
#   Notes: http://www.cdc.gov/growthcharts/percentile_data_files.htm
#   Created: 28 January 2016
#   Revisions: 
#     
#
#############################################################


if(.Platform$OS.type == "windows") {
  baseDir <- file.path("B:", "Projects/") } else {
    baseDir <- file.path("~", "Projects/") }
setwd(baseDir)
source("table_functions-knitr.R")
setwd("IeDEAS/TB")

# ages 2-20
cdc2 <- read.csv("Data/wtage.csv",na.string="")
# ages 0-3 (some overlap)
cdc1 <- read.csv("Data/wtageinf.csv",na.string="")


## remove overlap
cdc <- rbind(cdc1,cdc2[!(cdc2$Agemos %in% cdc1$Agemos),])

# Age is listed at the half month point for the entire month; for example, 1.5 months represents 1.0-1.99 months 
# or 1.0 month up to but not including 2.0 months of age. The only exception is birth, which represents the point at birth. 
d1$Agemos <- floor(12*as.numeric(d1$X8...Start.of.TB.treatment - d1$X4...Date.of.birth)/365.25)+0.5
d1$Agemos[d1$age.tbtreat==0] <- 0

## 1=male; 2=female
d1$Sex <- ifelse(d1$X5...Sex=="Male",1,2)

## merge our data with cdc data
d1 <- merge(d1,cdc,all.x=TRUE)

## formula from website
d1$zwei <- with(d1,((X10...Weight.at.start.of.TB.treatment.value/M)^L-1)/(L*S))

printz <- with(d1[order(d1$Agemos),],data.frame(Sex,Agemos,Weight=X10...Weight.at.start.of.TB.treatment.value,zwei))

## WHO program imputes these as missing because they are so implausible...
#    let's do the same
d1$zwei[!is.na(d1$zwei) & d1$zwei > 5] <- NA
d1$zwei[!is.na(d1$zwei) & d1$zwei < -6] <- NA


d1$zweigrp <- cut(d1$zwei,c(-6.1,-3,-2,5.1))
levels(d1$zweigrp) <- c("-6 SD$<$Z$<$-3 SD","-3 SD$<$Z$<$-2 SD","-2 SD$<$Z$<$5 SD")


setwd("Aim1")


