#############################################################
#
#   Program: lrm_model1.R
#   Project: IeDEA TB project 
#   PI:  
#   Statistican/Programmer: Meridith Blevins, MS
#   Purpose: 
#   Notes: 
#   Created: 8 December 2015
#   Revisions: 10 February 2016 -- use only CD4 count as linear
#              25 March 2016 -- incorporate Z-score and ART status
#     
#
#############################################################

d1$dx2artcat1 <- d1$dx2artcat
d1$dx2artcat1[d1$dx2artcat %in% c("$>$8 weeks after TB Dx","0-56 days after TB Dx")] <- "No ART"
d1$dx2artcat1 <- droplevels(d1$dx2artcat1)

d1$art.tbdx <- as.factor(d1$art.tbdx)
## some of this code was written by Sam Nwosu during Meridith's maternity leave
dat.model<-subset(d1,select=c(outcome1a,age.tbdx,X5...Sex,X10...Weight.at.start.of.TB.treatment.value,
                              combo_phase1a,microtest,region,microtest.2category,X25...CD4.cell.count.value,
                              X26...CD4.percent.value,cd4percent.missing,cd4.missing,art.tbdx,dx2artcat1,zwei))
dat.model$combo_phase1a <- as.factor(dat.model$combo_phase1a)
dat.model<-upData(dat.model,
                  outcome2.01=ifelse(outcome1a=="Unfavorable outcome",1,0),
                  rename=c(age.tbdx="Age",
                           X5...Sex="Gender",
                           X10...Weight.at.start.of.TB.treatment.value="Weight",
                           combo_phase1a="Treatment",
                           microtest.2category="Result",
                           region="Region",
                           X25...CD4.cell.count.value="CD4",
                           X26...CD4.percent.value="CD4percent"),
                  Region=as.factor(Region),
                  Region=factor(relevel(Region,ref="East Africa")),
                  Gender=relevel(Gender,ref="Male"),
                  Treatment=relevel(Treatment,ref="Isoniazid + Rifampin/Rifampicin + Pyrazinamide + Ethambutol"),
                  #                            Result=relevel(Result,ref="No test performed"),
                  Result=relevel(Result,ref="Negative/No test performed"))

dat.model$Result<-droplevels(dat.model$Result)
dat.model$Region<-as.factor(dat.model$Region)
# dat.model$sqrtCD4 <- sqrt(dat.model$CD4)

library(latticeExtra)
library(rms)
library(lmtest) ## for coeftest
library(sandwich) ## for sandwich
dd <- datadist(dat.model[c('outcome1a','Age', 'Gender', 'Weight','zwei', 'Treatment', 'Result', 'Region','CD4','CD4percent','art.tbdx','dx2artcat1')])
options(datadist='dd')

set.seed(8)
a1 <- aregImpute(~ Age + Gender + Weight + Treatment + Result + CD4 + CD4percent + art.tbdx + dx2artcat1 + zwei, n.impute=25,data=dat.model,nk=4)


model1.nl<-fit.mult.impute(outcome2.01 ~ rcs(Age,3) + rcs(zwei,3) + rcs(CD4,4) + Gender + Result + Treatment + art.tbdx + Region, fitter=lrm, xtrans=a1, data =dat.model)
model1.nl<-fit.mult.impute(outcome2.01 ~ rcs(Age,3) + zwei + rcs(CD4,4) + Gender + Result + Treatment + art.tbdx + Region, fitter=lrm, xtrans=a1, data =dat.model)
model1<-fit.mult.impute(outcome2.01 ~ Age + zwei + CD4 + Gender + Result + Treatment + art.tbdx + Region, fitter=lrm, xtrans=a1, data =dat.model,x=TRUE,y=TRUE)
model1art <-fit.mult.impute(outcome2.01 ~ Age + zwei + CD4 + Gender + Result + Treatment + dx2artcat1 + Region, fitter=lrm, xtrans=a1, data =dat.model,x=TRUE,y=TRUE)
## ART EFFECTS:
# summary(model1)[13:14,]
# summary(model1art)[13:16,]
# model1comp<-lrm(outcome2.01 ~ Age + zwei + CD4 + Gender + Result + Treatment + art.tbdx + Region, data =dat.model,x=TRUE,y=TRUE)
# 
# # p <- pentrace(model1comp, seq(0,10,by=.05))
# # plot(p)
# # p$diag      # may learn something about fractional effective d.f. 
# # # for each original parameter
# # pentrace(model1comp, list(simple=c(seq(0,10,0.5)), nonlinear=seq(0,5,0.25)))
# 
# model1a <- update(model1, penalty=5)
# effective.df(model1a)
# 
# plot(anova(model1a))
# validate(model1a,B=150)
# cal <- calibrate(model1a,B=150)
# plot(cal)

lrmsum <- summary(model1,Age=c(2,3),zwei=c(0,1),Gender="Male",CD4=c(50,60))[seq(2,22,by=2),]
lrmsumlines1 <- paste0(sapply(lrmsum[,4],myformat2)," (",sapply(lrmsum[,6],myformat2),", ",sapply(lrmsum[,7],myformat2),")")
lrmsumlines2 <- c(lrmsumlines1[1:7],"","1",lrmsumlines1[8:11])

lrm.labels <- c("Age (per 1 year)","Weight-for-age Z-score (per 1 SD)","CD4 (per 10 cells)","Female (vs. Male)",
                "At least 1 positive result (vs. Negative/No test performed)","No Ethambutol (vs. with Ethambutol)",
                "On ART at TB diagnosis",
                "Region","\\hspace{0.2in}East Africa (ref)","\\hspace{0.2in}Asia-Pacific","\\hspace{0.2in}Central Africa",
  "\\hspace{0.2in}Southern Africa","\\hspace{0.2in}West Africa")
model1pval <- as.data.frame(anova(model1))$P[c(1:8)]
pval1 <- c(sapply(model1pval[1:8],myformat4),rep("",5))
lrm1tex <- paste(lrm.labels,lrmsumlines2,pval1,sep=" & ",collapse=" \\\\ ")



lrmsum <- summary(model1art,Age=c(2,3),zwei=c(0,1),Gender="Male",CD4=c(50,60))[c(14,16),]
lrm1sumlines3 <- paste0(sapply(lrmsum[,4],myformat2)," (",sapply(lrmsum[,6],myformat2),", ",sapply(lrmsum[,7],myformat2),")")

